@@ -80,15 +80,17 @@ def delete_unuse_nominal_group(nominal_group_list):
     
     while i < len(nominal_group_list):
         #if a nominal group is an agent's proper noun, we remove it 
-        onto_class = []
-        try:
-            onto_class = ResourcePool().ontology_server.getDirectClassesOf(nominal_group_list[i].id)
-        except AttributeError:
+        onto_class = {}
+        if nominal_group_list[i].id:
+            try:
+                onto_class = ResourcePool().ontology_server.getDirectClassesOf(nominal_group_list[i].id)
+            except AttributeError:
+                pass
+        else:
+            # Nominal group with no ID? pass.
             pass
-        except KbError:
-            logger.debug("Nominal group with no ID. pass")
-            pass
-        
+
+
         if onto_class and "Agent" in onto_class.keys():
             nominal_group_list=nominal_group_list[:i]+nominal_group_list[i+1:]
             #When we delete => we increment i
@@ -121,24 +123,25 @@ def recover_nominal_group_list(sentences):
     Input=nominal group list                Output=nominal group list                     
     """
     
-    #init
-    nominal_group_list=[]
+    nominal_group_list = []
 
     #We recover all nominal groups of the sentences
-    for i in sentences:
-        nominal_group_list=nominal_group_list+i.sn
-        for j in i.sv:
-            nominal_group_list=nominal_group_list+j.d_obj
-            
-            for x in j.i_cmpl:
-                nominal_group_list=nominal_group_list+x.gn
-            nominal_group_list=nominal_group_list+recover_nominal_group_list(j.vrb_sub_sentence)
-    
-    
+    for sentence in sentences:
+        nominal_group_list += sentence.sn
+
+        for verb_group in sentence.sv:
+            nominal_group_list += verb_group.d_obj
+
+            for icmpl in verb_group.i_cmpl:
+                nominal_group_list += icmpl.gn
+
+            # recursively explore sub-sentences
+            nominal_group_list += recover_nominal_group_list(verb_group.vrb_sub_sentence)
+
     #We perform deletions
-    nominal_group_list=delete_redon_nominal_group(nominal_group_list)
-    nominal_group_list=delete_unuse_nominal_group(nominal_group_list)
-    
+    nominal_group_list = delete_redon_nominal_group(nominal_group_list)
+    nominal_group_list = delete_unuse_nominal_group(nominal_group_list)
+
     #If sentence is empty, we return an empty list      
     return nominal_group_list
 
@@ -149,23 +152,25 @@ def recover_nominal_group_list_without_id(sentences):
     return the list of the nominal groups used by anaphora processing                              
     Input=nominal group list                Output=nominal group list                     
     """
-    
-    #init
-    nominal_group_list=[]
+
+    nominal_group_list = []
 
     #We recover all nominal groups of the sentences
-    for i in sentences:
-        nominal_group_list=nominal_group_list+i.sn
-        for j in i.sv:
-            nominal_group_list=nominal_group_list+j.d_obj
-            
-            for x in j.i_cmpl:
-                nominal_group_list=nominal_group_list+x.gn
-            nominal_group_list=nominal_group_list+recover_nominal_group_list(j.vrb_sub_sentence)
-    
+    for sentence in sentences:
+        nominal_group_list += sentence.sn
+
+        for verb_group in sentence.sv:
+            nominal_group_list += verb_group.d_obj
+
+            for icmpl in verb_group.i_cmpl:
+                nominal_group_list += icmpl.gn
+
+            # recursively explore sub-sentences
+            nominal_group_list += recover_nominal_group_list(verb_group.vrb_sub_sentence)
+
     #We perform deletions
-    nominal_group_list=delete_unuse_nominal_group(nominal_group_list)
-    
+    nominal_group_list = delete_unuse_nominal_group(nominal_group_list)
+
     #If sentence is empty, we return an empty list      
     return nominal_group_list
 
