@@ -105,7 +105,7 @@ class Resolver:
             
             noun = ""
             try:
-                noun = '"' + nominal_group.noun[0].replace('+', ' ') + '"'
+                noun = nominal_group.noun[0].replace('+', ' ')
                 onto_res = ResourcePool().ontology_server.lookupForAgent(current_speaker, noun)
             except IndexError:
                 raise DialogError("We should not have to resolve nominal " + \
@@ -594,9 +594,12 @@ class Resolver:
                 historic_objects_list = recover_nominal_group_list(get_last(self.sentences_store, 10))
                 if not historic_objects_list:
                     raise DialogError("Error: possibly due to an empty dialog history")
-                
+
                 candidates = [obj for obj in historic_objects_list if obj.id in obj_list]
-                
+
+                if not candidates:
+                    logger.debug(colored_print("\tCould not find any suitable candidate from dialog history.", "magenta"))
+
                 # Discriminate everything different from this ID
                 for c in candidates:
                     current_stmts.append("?concept owl:differentFrom " + c.id)
@@ -799,10 +802,10 @@ class Resolver:
         except AttributeError:
             pass
             
-        if current_speaker != 'myself':
+        if current_speaker != ResourcePool().default_model:
             logger.debug(colored_print("Learning this new concept in robot's model: \n", "magenta") + '[' + colored_print(', '.join(stmts), None, 'magenta') + ']')
             try:
-                ResourcePool().ontology_server.revise(stmts, {"method":"add", "models":["myself"]})
+                ResourcePool().ontology_server.revise(stmts, {"method":"add", "models":[ResourcePool().default_model]})
             except AttributeError:
                 pass
 
