@@ -6,8 +6,6 @@ logger = logging.getLogger("dialogs")
 
 import os.path
 
-from kb import KB, KbError
-
 from dialog_exceptions import UnknownVerb
 
 def singleton(cls):
@@ -168,6 +166,8 @@ class ThematicRolesDict:
 @singleton
 class ResourcePool:
     
+    default_model = "default"
+
     def split_list(self, word_list):
                 
         #init
@@ -261,16 +261,23 @@ class ResourcePool:
         """
         self.thematic_roles = ThematicRolesDict()
 
-    def init(self, data_path, kb_host, kb_port):
+    def init(self, kb_host = "localhost", kb_port = 6969, embeddedkb = False, defaultontology = None, data_path = None):
+
+        if not data_path:
+            #try to guess the current prefix and then the data directory
+            data_path = os.path.abspath(__file__).split('lib')[0].split('src')[0] + 'share/dialogs/'
+            logger.debug("Assuming Dialogs data dir is <%s>" % data_path)
+
 
         try:
-            if kb_host:
-                self.ontology_server = KB(kb_host, kb_port)
-            else:
-                logger.warning("Starting without ontology server. Resolution won't work")
+            from kb import KB, KbError
+            self.ontology_server = KB(kb_host, kb_port, embeddedkb, defaultontology)
+        except ImportError:
+            logger.error("Python bindings to access the knowledge are not available." + \
+                            "Please install 'pykb' and restart Dialogs.")
         except KbError:
-            logger.error("Error while trying to connect to the knowledge base on " + kb_host + ":" + str(kb_port) + \
-            ". Continuing without knowledge base. Amongst others, resolution won't work.")
+            logger.error("Error while trying to connect to the knowledge base on %s:%s" % (kb_host, kb_port) + \
+                            ". Continuing without knowledge base. Amongst others, resolution won't work.")
 
         for line in open (os.path.join(data_path, "adjectives")):
             if line.startswith("#") or not line.strip():
@@ -398,7 +405,7 @@ class ResourcePool:
         #Add action verbs to the ontology
         if self.ontology_server:
             stmts = [verb.capitalize() + " rdfs:subClassOf cyc:PurposefulAction" for verb in self.thematic_roles.verbs.keys() if not self.thematic_roles.verbs[verb].is_synonym()]
-            self.ontology_server.revise(stmts, {"method":"add", "models":["myself"]})
+            self.ontology_server.revise(stmts, {"method":"add"})
         
         """
             List of ontology classes that are used in the adjectives list
@@ -418,7 +425,7 @@ class ResourcePool:
             ids = [ids]
 
         try:
-            self.ontology_server.revise([id + " rdf:type ActiveConcept" for id in ids], {"method":"add", "models":["myself"], "memory_profile": "SHORTTERM"})
+            self.ontology_server.revise([id + " rdf:type ActiveConcept" for id in ids], {"method":"add", "models":[ResourcePool().default_model], "lifespan": 10})
         except AttributeError:
             # No ontology server
             pass
